@@ -8,7 +8,7 @@ from contrast.extern.six import iteritems, string_types
 from contrast.agent.assess.contrast_event import ContrastEvent
 from contrast.agent.assess.properties import Properties
 from contrast.agent.assess.utils import get_properties
-from contrast.utils.assess.duck_utils import is_iterable, safe_iterator
+from contrast.utils.assess.duck_utils import is_iterable, safe_getattr, safe_iterator
 
 
 def cs__apply_trigger(
@@ -40,7 +40,7 @@ def cs__apply_trigger(
 
         return
 
-    if rule.is_violated(node, source):
+    if rule.is_violated(node, source, **dict(orig_args=args)):
         build_finding(
             context, rule, node, orig_source, self_obj, ret, possible_key, args, kwargs
         )
@@ -97,11 +97,9 @@ def build_finding(
         # event to it. In this case the stream object itself is actually
         # triggering the rule, which means that no data was necessarily read
         # from the stream before triggering the rule.
-        if getattr(target, "cs__source", False):
+        if safe_getattr(target, "cs__source", False):
             target_properties = Properties(target)
             target_properties.add_event(target.cs__source_event)
-        elif getattr(target, "cs__tracked", False):
-            target_properties = target.cs__properties
         else:
             target_properties = get_properties(target)
 
