@@ -22,13 +22,15 @@ from contrast.agent.assess.utils import (
     copy_tags_to_offset,
     copy_events,
     copy_from,
-    cs__tracked,
+    is_tracked,
     get_properties,
+    set_properties,
     track_string,
 )
 from contrast.utils.assess.duck_utils import (
     is_filelike,
     is_iterable,
+    safe_getattr,
     safe_iterator,
     len_or_zero,
 )
@@ -39,27 +41,19 @@ from contrast.extern import structlog as logging
 logger = logging.getLogger("contrast")
 
 
-class PropagationPolicy(object):
-    """
-    This class is responsible for the continuation of traces. A Propagator is any method that transforms an untrusted
-    value. In general, these methods work on the str class or a holder of str's
-    """
+def apply(nodes, preshift, ret):  # pylint: disable=redefined-builtin
+    if not nodes:
+        return
 
-    @staticmethod
-    def apply(nodes, preshift, self_obj, ret, args, kwargs=None):
+    for node in nodes:
+        if not preshift:
+            continue
 
-        if not nodes:
-            return
+        target = node.get_matching_first_target(
+            preshift.obj, ret, preshift.args, preshift.kwargs
+        )
 
-        for node in nodes:
-            if not preshift:
-                continue
-
-            target = node.get_matching_first_target(
-                preshift.obj, ret, preshift.args, preshift.kwargs
-            )
-
-            apply_propagator(node, preshift, target, ret, None)
+        apply_propagator(node, preshift, target, ret, None)
 
 
 def is_target_valid_length(target, action):
@@ -82,7 +76,7 @@ def track_copy_without_new_event(target, self_obj):
     This method should only be invoked in these special cases, and they should
     be documented heavily.
     """
-    if cs__tracked(self_obj):
+    if is_tracked(self_obj):
         track_string(target)
         copy_from(target, self_obj, 0, set())
 
@@ -99,7 +93,7 @@ def create_stream_event(node_type, stream, frame, args, kwargs):
     module = stream.__class__.__module__
     class_name = stream.__class__.__name__
 
-    source_type = getattr(stream, "cs__source_type", None) or "BODY"
+    source_type = safe_getattr(stream, "cs__source_type", None) or "BODY"
 
     if node_type == "source":
         node = SourceNode(
@@ -125,14 +119,15 @@ def create_stream_source_event(stream, frame, args, kwargs):
     if len(args) > 0:
         properties = get_properties(args[0])
         if properties is not None:
-            stream.cs__properties = Properties(stream)
-            copy_tags_to_offset(stream.cs__properties, properties.tags, 0)
-            copy_events(stream.cs__properties, properties)
+            stream_props = Properties(stream)
+            set_properties(stream, stream_props)
+            copy_tags_to_offset(stream_props, properties.tags, 0)
+            copy_events(stream_props, properties)
             prop_event = create_stream_event("propagation", stream, frame, args, kwargs)
             if prop_event is not None:
                 if len(properties.events) > 0:
                     prop_event.parent_ids = [properties.events[-1].event_id]
-                stream.cs__properties.add_event(prop_event)
+                stream_props.add_event(prop_event)
             stream.cs__tracked = True
 
 
@@ -151,8 +146,8 @@ def propagate_stream(method_name, target, self_obj, ret, frame, args, kwargs):
 
     elif (
         self_obj.cs__tracked
-        and self_obj.cs__properties
-        and self_obj.cs__properties.tags
+        and get_properties(self_obj)
+        and get_properties(self_obj).tags
     ):
         propagation_method = STREAM_ACTIONS.get(method_name)
         if propagation_method is None:
@@ -212,6 +207,7 @@ def propagate(method_name, target, self_obj, ret, frame, args, kwargs):
 SPLIT_PROPAGATOR_METHODS = ["split", "rsplit", "splitlines", "partition", "rpartition"]
 REGEX_MODULE = "re"
 REGEX_SPLIT = "split"
+REGEX_FINDALL = "findall"
 
 
 def cast_special_case(method_name, args, target):
@@ -262,11 +258,19 @@ def translate_special_case(method_name, self_obj, ret):
     )
 
 
-def is_string_split(propagator_node):
-    if (
-        propagator_node.module == REGEX_MODULE
-        and propagator_node.method_name == REGEX_SPLIT
-    ):
+def has_iterable_retval(propagator_node):
+    """
+    Returns True if given propagator node expects iterable list/tuple return value
+
+    Ordinarily, if we encounter a return value that is a list/tuple, we recurse down in
+    order to find simple strings. However, some propagators expect the return value to
+    be in an iterable, in which case we need to use the iterable itself to build the
+    preshift.
+    """
+    if propagator_node.module == REGEX_MODULE and propagator_node.method_name in [
+        REGEX_SPLIT,
+        REGEX_FINDALL,
+    ]:
         return True
     if propagator_node.class_name != "str":
         return False
@@ -284,7 +288,7 @@ def apply_propagator(propagator_node, preshift, target, ret, frame):
         for key, value in iteritems(target):
             apply_propagator(propagator_node, preshift, key, ret, frame)
             apply_propagator(propagator_node, preshift, value, ret, frame)
-    elif is_iterable(target) and not is_string_split(propagator_node):
+    elif is_iterable(target) and not has_iterable_retval(propagator_node):
         for item in safe_iterator(target):
             apply_propagator(propagator_node, preshift, item, ret, frame)
     else:
