@@ -8,8 +8,7 @@ from contrast.agent.assess.policy.propagators.base_propagator import (
     SUPPORTED_TYPES,
 )
 from contrast.agent.assess.utils import (
-    cs__splat_tags,
-    cs__tracked,
+    is_tracked,
     get_properties,
     track_string,
 )
@@ -49,7 +48,7 @@ class JsonPropagator(BasePropagator):
             return
 
         if isinstance(item, SUPPORTED_TYPES):
-            if cs__tracked(item):
+            if is_tracked(item):
                 self.apply_tags(item)
         elif isinstance(item, dict):
             for key, value in iteritems(item):
@@ -74,7 +73,7 @@ class JsonPropagator(BasePropagator):
             for event in item_properties.events:
                 target_properties.events.append(event)
 
-            cs__splat_tags(item, target)
+            self.splat_tags(item, target)
 
             target_properties.cleanup_tags()
 
