@@ -3,6 +3,7 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import re
 
+from contrast.agent import scope
 from contrast.agent.assess.adjusted_span import AdjustedSpan
 from contrast.agent.policy.loader import Policy
 from contrast.agent.assess.policy.preshift import Preshift
@@ -13,7 +14,6 @@ from contrast.agent.assess.utils import (
     get_properties,
     get_last_event_id,
     track_string,
-    update_properties,
 )
 from contrast.utils.decorators import fail_safely
 
@@ -202,11 +202,13 @@ def propagate_sub(node, target, repl_results, pattern, repl, string, count=0, **
     """
     Propagator for re.sub and re.subn
     """
-    source_matches = (
-        list(pattern.finditer(string))
-        if node.instance_method
-        else list(re.finditer(pattern, string, kwargs.get("flags", 0)))
-    )
+    with scope.contrast_scope():
+        # contrast scope required here to prevent analysis in finditer patch.
+        source_matches = (
+            list(pattern.finditer(string))
+            if node.instance_method
+            else list(re.finditer(pattern, string, kwargs.get("flags", 0)))
+        )
 
     # No propagation necessary because no replacement occurred
     if len(source_matches) == 0:
@@ -242,7 +244,6 @@ def propagate_sub(node, target, repl_results, pattern, repl, string, count=0, **
     )
 
     target_properties.cleanup_tags()
-    update_properties(target, target_properties)
 
 
 class RegexSplitPropagator(SplitPropagator):
@@ -264,15 +265,10 @@ class RegexSplitPropagator(SplitPropagator):
             return self.preshift.args[-1]
         return self.preshift.kwargs.get("flags", 0)
 
-    def propagate(self):
-        string = self.sources[0]
-        flags = self._get_flags()
-        pattern = self.preshift.obj if self.is_pattern_method else self.preshift.args[0]
-
-        source_properties = get_properties(string)
-        if source_properties is None:
-            return
+    def _get_pattern(self):
+        return self.preshift.obj if self.is_pattern_method else self.preshift.args[0]
 
+    def _propagate(self, string, flags, pattern, source_properties):
         source_offset = 0
         target_index = 0
 
@@ -292,10 +288,83 @@ class RegexSplitPropagator(SplitPropagator):
                     target_index += 1
                 source_offset += len(match.group())
 
-            target = self.target[target_index]
-            span = (source_offset, source_offset + len(target))
-            target_properties = copy_tags_in_span(target, source_properties, span)
-            copy_events(target_properties, source_properties)
+            if target_index < len(self.target):
+                target = self.target[target_index]
+                span = (source_offset, source_offset + len(target))
+                target_properties = copy_tags_in_span(target, source_properties, span)
+                copy_events(target_properties, source_properties)
 
-            source_offset += len(target)
-            target_index += 1
+                source_offset += len(target)
+                target_index += 1
+
+    def propagate(self):
+        string = self.sources[0]
+        flags = self._get_flags()
+        pattern = self._get_pattern()
+
+        source_properties = get_properties(string)
+        if source_properties is None:
+            return
+
+        self._propagate(string, flags, pattern, source_properties)
+
+
+class RegexFindallPropagator(RegexSplitPropagator):
+    def propagate(self):
+        """
+        Propagation action for re.findall and re.Pattern.findall
+
+        When the number of groups in the given pattern is 1 or 0 (which indicates an
+        implicit group corresponding to the whole pattern), findall returns a flat list
+        representing one result per match. In this case, the propagation action is
+        identical to the action for re.split, so we simply call the parent method.
+
+        When the number of groups is greater than 1, findall returns a list of tuples
+        where each tuple represents the groups corresponding to a given match. In this
+        case, we use finditer to get the corresponding Match instances in order to
+        determine the spans to use for propagation.
+        """
+        string = self.sources[0]
+        source_props = get_properties(string)
+        if source_props is None:
+            return
+
+        flags = self._get_flags()
+        pattern = re.compile(self._get_pattern())
+        if pattern.groups < 2:
+            self._propagate(string, flags, pattern, source_props)
+            return
+
+        # We know we're in scope here, so we're safe to call finditer
+        matches = (
+            pattern.finditer(string)
+            if self.is_pattern_method
+            else re.finditer(pattern, string, flags)
+        )
+
+        for target, match in zip(self.target, matches):
+            for i, result in enumerate(target):
+                target_properties = copy_tags_in_span(
+                    result,
+                    source_props,
+                    # skip the first span since it duplicates the entire match
+                    match.span(i + 1),
+                )
+
+                # This can be None if len(target) < 2
+                if target_properties is None:
+                    continue
+
+                parent_ids = [get_last_event_id(source_props)]
+
+                copy_events(target_properties, source_props)
+
+                target_properties.build_event(
+                    self.node,
+                    result,
+                    self.preshift.obj,
+                    result,
+                    self.preshift.args,
+                    self.preshift.kwargs,
+                    parent_ids,
+                )
