@@ -3,7 +3,7 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.extern import six
 
-from contrast.agent.assess.utils import cs__splat_tags, copy_from
+from contrast.agent.assess.utils import copy_from
 from contrast.agent.assess.policy.propagators.base_propagator import BasePropagator
 
 
@@ -34,4 +34,4 @@ class ReprPropagator(BasePropagator):
             return
 
         # If it's not, then just splat to account for encoding, etc.
-        cs__splat_tags(self.first_source, self.target)
+        self.splat_tags(self.first_source, self.target)
