@@ -9,8 +9,7 @@ from contrast.agent.assess.policy.propagators.base_propagator import (
 )
 from contrast.agent.assess.utils import (
     copy_from,
-    cs__splat_tags,
-    cs__tracked,
+    is_tracked,
     get_properties,
     track_string,
 )
@@ -83,7 +82,7 @@ class SplatPropagator(BasePropagator):
         tracked_inputs = []
 
         def _append_if_tracked(val):
-            if cs__tracked(val):
+            if is_tracked(val):
                 tracked_inputs.append(val)
 
         for source in self.sources:
@@ -110,6 +109,6 @@ class SplatPropagator(BasePropagator):
                 for event in item_properties.events:
                     self.target_properties.events.append(event)
 
-                cs__splat_tags(item, self.target)
+                self.splat_tags(item, self.target)
 
         self.target_properties.cleanup_tags()
