@@ -31,7 +31,6 @@ class SourceNode(PolicyNode):
         policy_patch=True,
         python2_only=False,
         python3_only=False,
-        builtin=False,
     ):
         super(SourceNode, self).__init__(
             module,
@@ -44,7 +43,6 @@ class SourceNode(PolicyNode):
             policy_patch=policy_patch,
             python2_only=python2_only,
             python3_only=python3_only,
-            builtin=builtin,
         )
 
         self.package = package
@@ -158,5 +156,4 @@ class SourceNode(PolicyNode):
             policy_patch=obj.get(constants.JSON_POLICY_PATCH, True),
             python2_only=obj.get(constants.JSON_PY2_ONLY, False),
             python3_only=obj.get(constants.JSON_PY3_ONLY, False),
-            builtin=obj.get(constants.JSON_BUILTIN, False),
         )
