@@ -3,7 +3,7 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 import cgi
 
-from contrast.extern.six import iteritems, PY2
+from contrast.extern.six import integer_types, iteritems, PY2
 from contrast.extern.six.moves.collections_abc import Mapping
 
 import contrast
@@ -13,56 +13,69 @@ from contrast.agent.assess.properties import Properties
 from contrast.agent.assess.utils import (
     get_properties,
     get_last_event_ids_from_sources,
+    is_trackable,
+    set_properties,
     track_string,
-    update_properties,
-    value_of_source,
 )
-from contrast.utils.assess.duck_utils import is_iterable, safe_iterator
+from contrast.agent.policy.constants import OBJECT, RETURN
+from contrast.agent.settings_state import SettingsState
+from contrast.utils.assess.duck_utils import is_iterable, safe_getattr, safe_iterator
 from contrast.utils.decorators import fail_safely
 from contrast.utils.string_utils import truncated_signature
-from contrast.agent.settings_state import SettingsState
 
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
 try:
-    # We only need this if werkzeug is actually installed
-    # It is necessary since this is not a subclass of dict/Mapping
-    from werkzeug.datastructures import EnvironHeaders
+    from werkzeug.datastructures import EnvironHeaders, FileStorage
 
-    werkzeug_headers = (EnvironHeaders,)
+    EnvironHeaders_types = (EnvironHeaders,)
+    FileStorage_types = (FileStorage,)
 except ImportError:
-    werkzeug_headers = ()
+    EnvironHeaders_types = ()
+    FileStorage_types = ()
 
 
-class SourcePolicy(object):
-    @staticmethod
-    def apply(source_nodes, self_obj, ret, args, kwargs=None):
-        """
-        Apply node into all sources to track all new strings coming in from a request
-        """
-        context = contrast.CS__CONTEXT_TRACKER.current()
-        if context is None or not SettingsState().is_assess_enabled():
-            return
+def apply(
+    source_nodes, self_obj, ret, args, kwargs=None
+):  # pylint: disable=redefined-builtin
+    """
+    Apply node into all sources to track all new strings coming in from a request
+    """
+    context = contrast.CS__CONTEXT_TRACKER.current()
+    if context is None or not SettingsState().is_assess_enabled():
+        return
 
-        for node in source_nodes:
+    for node in source_nodes:
 
-            # args[0] is `self` for instance methods
-            args = args[1:] if node.instance_method else args
+        # args[0] is `self` for instance methods
+        args = args[1:] if node.instance_method else args
 
-            target = node.get_matching_first_target(self_obj, ret, args, kwargs)
-            if hasattr(target, "cs__source"):
-                # Target is already a source, nothing to do
-                if target.cs__source:
-                    return
+        target = node.get_matching_first_target(self_obj, ret, args, kwargs)
 
-                target.cs__source = True
-                target.cs__source_type = node.type
-                target.cs__source_tags = node.tags
-                target.cs__properties = Properties(target)
+        source_type = node.type
+        if isinstance(target, FileStorage_types):
+            # We don't try to propagate through werkzeug's file parsing logic, because
+            # it causes massive slowdown. Instead, if we see a FileStorage object
+            # come out of a multidict, we track it. We need to track the underlying
+            # stream, not the FileStorage object itself.
+            target = target.stream if PY2 else target.stream._file
+            source_type = "MULTIPART_CONTENT_DATA"
 
-            cs__apply_source(context, node, target, self_obj, ret, args, kwargs)
+        if hasattr(target, "cs__source"):
+            # Target is already a source, nothing to do
+            if target.cs__source:
+                return
+
+            target.cs__source = True
+            target.cs__source_type = source_type
+            target.cs__source_tags = node.tags
+            set_properties(target, Properties(target))
+
+        cs__apply_source(
+            context, node, target, self_obj, ret, args, kwargs, source_type=source_type
+        )
 
 
 def adjust_source_tags(tags, source_type, source_name):
@@ -96,8 +109,8 @@ def apply_stream_source(method_name, target, self_obj, ret, args, kwargs):
     module = self_obj.__class__.__module__
     class_name = self_obj.__class__.__name__
 
-    source_type = getattr(self_obj, "cs__source_type", None) or "BODY"
-    source_tags = getattr(self_obj, "cs__source_tags", None) or ["UNTRUSTED"]
+    source_type = safe_getattr(self_obj, "cs__source_type", None) or "BODY"
+    source_tags = safe_getattr(self_obj, "cs__source_tags", None) or ["UNTRUSTED"]
 
     node = SourceNode(
         module,
@@ -141,14 +154,22 @@ def _get_source_name(node, self_obj, args):
     Otherwise, use the method name (e.g. for `flask.wrappers.Request.full_path`, the
     source name will be "full_path").
     """
-    if args and isinstance(self_obj, (dict, Mapping) + werkzeug_headers):
+    if args and isinstance(self_obj, (dict, Mapping) + EnvironHeaders_types):
         return args[0]
 
     return node.method_name
 
 
 def cs__apply_source(
-    context, node, target, self_obj, ret, args, kwargs, source_name=None
+    context,
+    node,
+    target,
+    self_obj,
+    ret,
+    args,
+    kwargs,
+    source_name=None,
+    source_type=None,
 ):
     # target: {param: test} / QueryDict
     # self_obj: QueryDict
@@ -156,12 +177,23 @@ def cs__apply_source(
     # args: param
 
     logger.debug("In cs__apply_source for %r", node)
+    if source_type is None:
+        source_type = node.type
 
-    if node.type in NAMED_SOURCE_TYPES and not source_name:
+    if source_type in NAMED_SOURCE_TYPES and not source_name:
         source_name = _get_source_name(node, self_obj, args)
 
     _cs__apply_source(
-        context, node, target, self_obj, ret, node.type, source_name, True, args, kwargs
+        context,
+        node,
+        target,
+        self_obj,
+        ret,
+        source_type,
+        source_name,
+        True,
+        args,
+        kwargs,
     )
 
 
@@ -178,19 +210,15 @@ def _cs__apply_source(
     args,
     kwargs,
 ):
-
     if not context or not node or target is None:
         return
 
-    if hasattr(target, "cs__properties"):
-        target_properties = target.cs__properties
-    else:
-        target_properties = get_properties(target)
-        if target_properties is None:
-            target_properties = track_string(target)
+    target_properties = get_properties(target)
+    if target_properties is None and is_trackable(target):
+        target_properties = track_string(target)
 
     if target_properties is not None:
-        if not getattr(target, "cs__source", False):
+        if not safe_getattr(target, "cs__source", False):
             for tag in adjust_source_tags(node.tags, source_type, source_name):
                 length = len(target)
 
@@ -218,10 +246,8 @@ def _cs__apply_source(
             source_name=source_name,
         )
 
-        if hasattr(target, "cs__properties"):
-            target.cs__properties = target_properties
-        else:
-            update_properties(target, target_properties)
+        if is_trackable(target):
+            set_properties(target, target_properties)
 
     elif isinstance(target, dict):
         # This logic is intended to handle the case where the source is a dict
@@ -306,6 +332,25 @@ def _cs__apply_source(
             )
 
 
+def value_of_source(source, self_obj, ret, args, kwargs):
+    if source == OBJECT:
+        return self_obj
+
+    if source == RETURN:
+        return ret
+
+    if not args:
+        return self_obj
+
+    if args and isinstance(source, integer_types) and source < len(args):
+        return args[source]
+
+    if kwargs and source in kwargs:
+        return kwargs[source]
+
+    return None
+
+
 def get_parent_ids(node, self_obj, ret, args, kwargs):
     if isinstance(node, SourceNode):
         return []
