@@ -9,7 +9,7 @@ class NonDataflowRule(TriggerRule):
     Rule class used for all non-dataflow rules (i.e. crypto rules).
     """
 
-    def update_preflight_hash(self, hasher, source=None):
+    def update_preflight_hash(self, hasher, source=None, **kwargs):
         """
         This gets called from `create_finding` in the base class
         """
