@@ -3,7 +3,6 @@
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
 from contrast.agent.service_client import send_messages
 from contrast.agent.assess.rules.base_rule import BaseRule
-from contrast.agent.settings_state import SettingsState
 from contrast.api import Finding
 from contrast.api.dtm_pb2 import Activity
 
@@ -20,10 +19,7 @@ class StaticRule(BaseRule):
         finding_msg = Finding(self, properties, **kwargs).get_finding_msg()
         finding_msg.version = Finding.pick_version(finding_msg)
 
-        settings = SettingsState()
-
         activity = Activity()
-        activity.finding_tags = settings.config.get("assess.tags")
         activity.findings.extend([finding_msg])
 
         send_messages([activity])
