@@ -7,6 +7,7 @@ from contrast.agent.policy.trigger_node import TriggerNode
 from contrast.agent.assess.rules.base_rule import BaseRule
 from contrast.agent.assess.utils import get_properties
 from contrast.api import Finding
+from contrast.utils.assess.duck_utils import safe_getattr
 from contrast.utils.decorators import cached_property
 from contrast.utils.string_utils import equals_ignore_case
 
@@ -88,9 +89,9 @@ class TriggerRule(BaseRule):
                     )
                 )
 
-    def _is_violated(self, node, source_properties):
+    def _is_violated(self, node, source_properties, **kwargs):
         return node.trigger_action.is_violated(
-            source_properties, self.required_tags, self.disallowed_tags
+            source_properties, self.required_tags, self.disallowed_tags, **kwargs
         )
 
     def is_violated_properties(self, node, properties):
@@ -99,21 +100,17 @@ class TriggerRule(BaseRule):
         """
         return self._is_violated(node, properties)
 
-    def is_violated(self, node, source):
+    def is_violated(self, node, source, **kwargs):
         """
         Determine whether rule was violated based on source object
         """
         # The rule is violated if the object is marked as source
-        if getattr(source, "cs__source", False):
+        if safe_getattr(source, "cs__source", False):
             return True
 
-        if hasattr(source, "cs__tracked"):
-            # Using getattr for safety, even though we know it's there
-            source_properties = getattr(source, "cs__properties", None)
-        else:
-            source_properties = get_properties(source)
+        source_properties = get_properties(source)
 
-        return self._is_violated(node, source_properties)
+        return self._is_violated(node, source_properties, **kwargs)
 
     def extract_source(self, node, source):
         """
