@@ -10,5 +10,5 @@ class SessionTimeoutRule(TriggerConfigRule, SessionAgeRuleMixin):
         """Override for safety. In theory, this should never be called."""
         return False
 
-    def is_violated(self, node, source):
+    def is_violated(self, node, source, **kwargs):
         return SessionAgeRuleMixin.is_violated(self, source)
