@@ -9,7 +9,7 @@ from contrast.extern.six import PY2, binary_type, string_types, text_type
 
 from contrast.agent import scope
 from contrast.assess_extensions import cs_str
-from contrast.utils.decorators import fail_safely
+from contrast.utils.decorators import fail_quietly
 from contrast.utils.string_utils import truncated_signature
 
 from contrast.extern import structlog as logging
@@ -113,7 +113,7 @@ class StringTracker(OrderedDict):
         for k in self:
             yield (k, self.get_by_id(k))
 
-    @fail_safely("Failure in string tracker ageoff")
+    @fail_quietly("Failure in string tracker ageoff")
     def ageoff(self):
         """Age-off string tracker entries older than predefined threshold"""
         now = time.time()
@@ -122,7 +122,15 @@ class StringTracker(OrderedDict):
             props = super(StringTracker, self).__getitem__(key)
             if (now - props.timestamp) > self.AGE_OFF_THRESHOLD_SECS:
                 self.log_ageoff(props.origin)
-                super(StringTracker, self).__delitem__(key)
+                try:
+                    super(StringTracker, self).__delitem__(key)
+                except KeyError:
+                    # Handles potential race condition that may occur if
+                    # another thread may have already deleted the key after
+                    # this thread gets the key but before it deletes it.
+                    # More likely to happen in multi-threaded apps and if
+                    # and app receives many requests per second.
+                    pass
             else:
                 # Since the dictionary is ordered, when we encounter the first
                 # string younger than the threshold we can break the loop.
