@@ -1,45 +1,36 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import integer_types
-
 import contrast
 from contrast.agent.assess.adjusted_span import AdjustedSpan
-from contrast.agent.policy.constants import OBJECT, RETURN
+from contrast.utils.assess.duck_utils import safe_getattr
 from contrast.utils.assess.tag_utils import merge_tags
 
 
 def get_properties(value):
-    return contrast.STRING_TRACKER.get(value, None)
+    return safe_getattr(value, "cs__properties", None)
 
 
-def update_properties(value, properties):
-    contrast.STRING_TRACKER.update_properties(value, properties)
+def set_properties(obj, props):
+    obj.cs__properties = props
 
 
 def clear_properties():
     contrast.STRING_TRACKER.clear()
 
 
-def cs__tracked(value):
-    props = get_properties(value)
-    return props is not None and props.is_tracked()
+def is_trackable(obj):
+    return hasattr(obj, "cs__properties")
+
+
+def is_tracked(value):
+    return bool(get_properties(value))
 
 
 def track_string(value):
     return contrast.STRING_TRACKER.track(value)
 
 
-def in_string_tracker(value):
-    return value in contrast.STRING_TRACKER
-
-
-def cs__reset_properties(value):
-    from contrast.agent.assess.properties import Properties
-
-    contrast.STRING_TRACKER.__setitem__(value, Properties(value))
-
-
 def copy_events(target_props, source_props):
     if source_props is None or target_props is None or target_props is source_props:
         return
@@ -53,7 +44,7 @@ def copy_from(to_obj, from_obj, shift=0, skip_tags=None):
     if from_obj is to_obj:
         return
 
-    if not cs__tracked(from_obj):
+    if not is_tracked(from_obj):
         return
 
     from_props = get_properties(from_obj)
@@ -62,7 +53,7 @@ def copy_from(to_obj, from_obj, shift=0, skip_tags=None):
     to_props = get_properties(to_obj)
 
     if from_props == to_props:
-        cs__reset_properties(to_obj)
+        return
 
     copy_events(to_props, from_props)
 
@@ -85,76 +76,6 @@ def copy_from(to_obj, from_obj, shift=0, skip_tags=None):
             to_props.set_tag(key, new_tags)
 
 
-def cs__splat_tags(value, ret, source=None):
-    if source is None:
-        source = value
-
-    length = len(ret)
-
-    for key in get_properties(source).tag_keys():
-
-        existing_props = get_properties(ret)
-
-        if not existing_props:
-            continue
-
-        existing_tags = existing_props.fetch_tags(key)
-
-        if existing_tags and len(existing_tags) > 1:
-            del existing_tags[len(existing_tags) - 1]
-
-            span = existing_tags[0]
-
-            span.repurpose(0, length)
-        else:
-            span = AdjustedSpan(0, length)
-
-            ret_properties = get_properties(ret)
-            ret_properties.add_tag(key, span)
-
-            update_properties(ret, ret_properties)
-
-        if not cs__tracked(ret):
-            return
-
-
-def value_of_source(source, self_obj, ret, args, kwargs):
-    if source == OBJECT:
-        return self_obj
-
-    if source == RETURN:
-        return ret
-
-    if not args:
-        return self_obj
-
-    if args and isinstance(source, integer_types) and source < len(args):
-        return args[source]
-
-    if kwargs and source in kwargs:
-        return kwargs[source]
-
-    return None
-
-
-def cs__apply_tags(node, target, span=None):
-    target_properties = get_properties(target)
-    if not target_properties:
-        return
-
-    span = span or AdjustedSpan(0, len(target))
-    for tag in node.tags:
-        target_properties.add_tag(tag, span)
-
-
-def cs__apply_untags(node, target):
-    target_properties = get_properties(target)
-
-    if target_properties:
-        for tag in node.untags:
-            target_properties.delete_tag(tag)
-
-
 def get_self_for_method(patch_policy, args):
     """
     Retrieves self for a method's PatchLocationPolicy,
@@ -211,7 +132,6 @@ def copy_tags_in_span(target, source_properties, span, offset=0):
             target_properties.add_existing_tag(name, tag)
 
     merge_tags(target_properties.tags)
-    update_properties(target, target_properties)
     return target_properties
 
 
