@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.utils.exceptions.disable_agent_exception import DisableAgentException
-
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
@@ -18,4 +16,3 @@ class DisableReaction(object):
 
         if settings.config:
             settings.config.put(DisableReaction.ENABLE, False)
-            raise DisableAgentException
