@@ -4,7 +4,7 @@
 from pip._vendor import pkg_resources
 from collections import namedtuple
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
