@@ -15,11 +15,10 @@ logger = logging.getLogger("contrast")
 class Heartbeat(threading.Thread):
     def __init__(self, settings):
         super(Heartbeat, self).__init__()
+        self.daemon = True
         self.settings = settings
         self.stopped = False
 
-        logger.debug("Establishing heartbeat")
-
         self.heartbeat_interval_ms = self.settings.config.get(
             "agent.polling.app_activity_ms", 30000
         )
@@ -30,13 +29,18 @@ class Heartbeat(threading.Thread):
             self.heartbeat_interval_ms = 10000
             self.heartbeat_interval_sec = 10
 
+    def get_sleep_time(self):
+        return self.heartbeat_interval_sec
+
     def run(self):
         # Ensure the heartbeat thread runs in scope because it is initialized
         # before our thread.start patch is applied.
         with scope.contrast_scope():
-            while not self.stopped:
+            logger.debug("Establishing heartbeat")
+
+            while not self.stopped and self.settings.is_agent_config_enabled():
                 self.send_heartbeat()
-                time.sleep(self.heartbeat_interval_sec)
+                time.sleep(self.get_sleep_time())
 
     @fail_safely("Error sending a heartbeat message")
     def send_heartbeat(self):
