@@ -8,9 +8,10 @@ import platform
 import sys
 
 from contrast import __version__
+from contrast.agent.patch_controller import disable_assess_patches
 from contrast.agent import patch_controller, service_client, scope
 from contrast.agent.policy.loader import Policy
-from contrast.agent.assess.policy.trigger_policy import TriggerPolicy
+from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.assess.preflight import update_preflight_hashes
 from contrast.agent.assess.rules.providers.enable import enable_providers
 from contrast.agent.middlewares.route_coverage.routes_mixin import RoutesMixin
@@ -21,7 +22,7 @@ from contrast.utils.decorators import cached_property
 from contrast.utils.exceptions.contrast_service_exception import (
     ContrastServiceException,
 )
-from contrast.utils.exceptions.disable_agent_exception import DisableAgentException
+from contrast.extern.six import PY2
 from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.library_reader.library_reader import LibraryReader
 from contrast.utils.loggers.logger import setup_agent_logger, setup_basic_agent_logger
@@ -55,6 +56,7 @@ class BaseMiddleware(RoutesMixin):
         "A security filter prevented original response from being returned."
     )
     LOGS_SEPARATOR = "-" * 120
+    PY2_DEPRECATION_MSG = "[Contrast Security] [DEPRECATION] Support for Python 2.7  will be removed in 2021. Please contact Customer Support prior if you require continued support."
 
     def __init__(self):
         # use _loaded to call our middleware only once because of runserver and WSGIHandler being initialized twice.
@@ -64,6 +66,7 @@ class BaseMiddleware(RoutesMixin):
         # id to distinguish middlewares created by different processes
         self.id = id(self)
 
+        self.log_deprecation()
         self.log_initialize()
 
         self.settings = None
@@ -117,7 +120,7 @@ class BaseMiddleware(RoutesMixin):
         """
         try:
             self.settings = SettingsState(app_name=app_name)
-        except (Exception, DisableAgentException) as e:
+        except Exception as e:
             logger.error(e)
             return False
         return True
@@ -204,9 +207,18 @@ class BaseMiddleware(RoutesMixin):
 
     def call_without_agent(self):
         """
-        If Agent was not initialized due to either entire settings initialization failing
+        If Agent is either disabled or not initialized due to either entire settings initialization failing
         or just loggers failing, then we should print to stdout that the Agent is not running.
+
+        In the case of the agent is disabled by a reaction from SR, we have to disable assess patches here
+        because checking for context inside of our builtin string patches is much more expensive to do since
+        they are called very frequently.
+
+        The agent does not set context when this function is called so all other patches (e.g propagators) that check
+        context shouldn't run.
         """
+        disable_assess_patches()
+
         logger.warning("Contrast Agent is not running.")
 
     def handle_ensure(self, context, request):
@@ -418,7 +430,7 @@ class BaseMiddleware(RoutesMixin):
         # If/when we consolidate all scope levels, this scope should be removed
         # entirely since the postfilter is already in scope when it's called.
         with scope.trigger_scope():
-            TriggerPolicy.apply(rule, [trigger_node], result, args, {})
+            trigger_policy.apply(rule, [trigger_node], result, args, {})
 
     def postfilter_assess(self, context):
         """
@@ -490,6 +502,13 @@ class BaseMiddleware(RoutesMixin):
             "Ending request analysis", request_path=request_path,
         )
 
+    def log_deprecation(self):
+        if PY2:
+            warn_color = "\033[91m"
+            end_color = "\033[0m"
+            print("\n{}{}{}\n".format(warn_color, self.PY2_DEPRECATION_MSG, end_color))
+            logger.warning(self.PY2_DEPRECATION_MSG)
+
     def log_initialize(self):
         logger.info(
             "Initializing Contrast Agent %s [id=%s]", self.__class__.__name__, self.id
