@@ -4,7 +4,7 @@
 from contrast.extern.six import iteritems
 
 from contrast.agent import scope
-from contrast.agent.assess.policy.utils import skip_analysis
+from contrast.agent.assess.policy.analysis import skip_analysis
 from contrast.agent.assess.policy.source_node import SourceNode
 from contrast.agent.assess.policy.source_policy import cs__apply_source
 from contrast.utils.assess.stream_utils import ContrastWsgiStreamProxy
@@ -12,7 +12,9 @@ from contrast.utils.decorators import fail_safely
 
 
 # a best effort at translating the types in this document:
-# https://bitbucket.org/contrastsecurity/teamserver/src/862d499227e8eac42b6eb7c6b03f10b7f1556218/teamserver-agent-messages/src/main/java/contrast/agent/messages/finding/trace/EventSourceTypeDTM.java#lines-8
+# https://bitbucket.org/contrastsecurity/teamserver/src/
+# 862d499227e8eac42b6eb7c6b03f10b7f1556218/teamserver-agent-messages/src/main/java/
+# contrast/agent/messages/finding/trace/EventSourceTypeDTM.java#lines-8
 ENVIRON_SOURCES = {
     "CONTENT_LENGTH": "HEADER",
     "CONTENT_TYPE": "HEADER",
@@ -34,11 +36,10 @@ SOURCE_TAGS = {"HEADER": ["NO_NEWLINES"], "PARAMETER": ["CROSS_SITE"]}
 
 SOURCE_DICT = {"module": "wsgi.environ", "instance_method": False, "target": "RETURN"}
 
-WEBOB_KEYS = {
+WEBOB_KEYS_TO_DELETE = {
     "webob._parsed_query_vars",
     "webob._parsed_post_vars",
     "webob._body_file",
-    "webob.is_body_seekable",
     "webob._parsed_cookies",
     "webob._cache_control",
 }
@@ -77,7 +78,8 @@ def track_environ_sources(framework, context, environ, skip_wsgi_input=False):
         for key, value in iteritems(environ):
             _track_environ_item(framework, context, environ, key, value)
 
-        _track_wsgi_input(environ, skip_wsgi_input)
+        if not skip_wsgi_input:
+            _track_wsgi_input(environ)
         _remove_webob_environ_vars(environ)
 
 
@@ -147,8 +149,8 @@ def _track_environ_item(framework, context, environ, key, value):
         cs__apply_source(context, key_node, key, environ, key, (), {}, source_name=key)
 
 
-def _track_wsgi_input(environ, skip_wsgi_input):
-    if "wsgi.input" in environ and not skip_wsgi_input:
+def _track_wsgi_input(environ):
+    if "wsgi.input" in environ:
         if not hasattr(environ["wsgi.input"], "cs__source"):
             environ["wsgi.input"] = ContrastWsgiStreamProxy(environ["wsgi.input"])
 
@@ -173,11 +175,12 @@ def _remove_webob_environ_vars(environ):
     info using our now-tracked environ values. In the future, we should instead iterate
     over these entries and track their values explicitly, for the sake of performance.
 
-    Another consequence of deleting these variables is that their values will necessarily
-    be webob types for which we have patches. Since our request wrapper is a subclass of
-    contrast.extern.webob.BaseRequest, we were ending up with _our_ externed webob objects
-    in the application's environ. We don't have or want patches for our own externed webob,
-    so this ensures that all of webob's cached environ values will have patches.
+    Another consequence of deleting these variables is that their values will
+    necessarily be webob types for which we have patches. Since our request wrapper is a
+    subclass of contrast.extern.webob.BaseRequest, we were ending up with _our_ externed
+    webob objects in the application's environ. We don't have or want patches for our
+    own externed webob, so this ensures that all of webob's cached environ values will
+    have patches.
 
     We should always check to see if these values are present, even if we're inside
     of a framework that doesn't explicitly use webob. This is because it's possible that
@@ -198,7 +201,8 @@ def _remove_webob_environ_vars(environ):
 
     webob.adhoc_attrs
         A custom dictionary of arbitrary data passed between middlewares. We make a best
-        effort to patch this, and we don't delete it, because we can't know much about it
+        effort to patch this, and we don't delete it, because we can't know much about
+        it.
 
     webob._body_file
         A 2-tuple
@@ -209,12 +213,16 @@ def _remove_webob_environ_vars(environ):
 
     webob.is_body_seekable
         A boolean
-        - Created/set to True once webob replaces wsgi.input with a seekable file-like object
+        - Created/set to True once webob replaces wsgi.input with a seekable file-like
+          object
         - Assumed to be False if missing
+        - We do not remove this from environ, because we don't want webob to replace
+          wsgi.input if possible (since by this point we've made it a source)
 
     webob._parsed_cookies
         A 2-tuple
-        - first element is a dict of cookie keys to cookie values (parsed from HTTP_COOKIE)
+        - first element is a dict of cookie keys to cookie values (parsed from
+          HTTP_COOKIE)
         - second element is the HTTP_COOKIE string that was parsed to produce element #1
 
     webob._cache_control
@@ -224,13 +232,13 @@ def _remove_webob_environ_vars(environ):
 
     webob.url_encoding
         A string
-        - Used to store the string encoding of the URL. We don't delete it because it's easy
-        to track directly. In the future we might want to look into whether we need to track
-        this at all.
+        - Used to store the string encoding of the URL. We don't delete it because it's
+          easy to track directly. In the future we might want to look into whether we
+          need to track this at all.
 
     :param environ: WSGI environ dict
     :return: None
     """
-    for key in WEBOB_KEYS:
+    for key in WEBOB_KEYS_TO_DELETE:
         if key in environ:
             del environ[key]
