@@ -91,25 +91,24 @@ class DjangoMiddleware(DjangoBaseMiddleware):
         """
         Process exception is called when a view raises an exception
 
-        We check if the exception is our own and handle it accordingly
+        We check if the exception is our own and handle it accordingly. We make sure to
+        send any findings that may have occurred prior to the exception. This enables
+        us to trigger findings even when the trigger function itself calls an
+        exception.
         """
         try:
             return self.handle_exception(exception)
         except ContrastServiceException as e:
             logger.warning(e)
             return self.call_without_agent(request)
+        except Exception:
+            self.handle_ensure(self.context, request)
+            raise
 
     def process_response(self, request, response):
         """
         Process response wraps the response and then runs the postfilter rules
         """
-        if response.__class__.__name__ in [
-            "HttpResponsePermanentRedirect",
-            "HttpResponseServerError",
-        ]:
-            # Ignore redirects that could come before the process_request
-            return response
-
         if self.context is None:
             return response
 
