@@ -1,16 +1,10 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
-from contrast.extern.six import iteritems
-
 import contrast
-from contrast.agent.assess.policy.source_policy import cs__apply_source
 from contrast.agent.policy.trigger_node import TriggerNode
 from contrast.agent.middlewares.base_middleware import BaseMiddleware
-from contrast.agent.middlewares.environ_tracker import (
-    build_source_node,
-    track_environ_sources,
-)
+from contrast.agent.middlewares.environ_tracker import track_environ_sources
 from contrast.agent.middlewares.route_coverage.pyramid_routes import (
     create_pyramid_routes,
     get_view_func,
@@ -23,49 +17,37 @@ from contrast.utils.exceptions.contrast_service_exception import (
 )
 
 from contrast.extern import structlog as logging
+from pyramid.interfaces import IRoutesMapper
 
 logger = logging.getLogger("contrast")
 
-
-REQUEST_SOURCES = {
-    "body": "BODY",
-    "host_url": "PARAMETER",
-    "path": "PARAMETER",
-    "path_info": "PARAMETER",
-    "query_string": "PARAMETER",
-    "remote_addr": "PARAMETER",
-    "text": "BODY",
-    "url": "PARAMETER",
-}
-
 WEBOB = "webob"
 
 
 class PyramidMiddleware(BaseMiddleware):
     def __init__(self, handler, registry):
-        self.app_name = self.get_app_name(registry)
+        self.registry = registry
+        self.app_name = self.get_app_name()
 
         super(PyramidMiddleware, self).__init__()
 
         self.handler = handler
 
-    def get_app_name(self, registry):
+    def get_app_name(self):
         try:
-            return registry.package_name
+            return self.registry.package_name
         except Exception:
             return "pyramid_app"
 
     def __call__(self, request):
         if self.is_agent_enabled() and request:
-            environ = request.environ
-
-            context = RequestContext(environ)
+            context = RequestContext(request.environ)
 
             if self.settings.is_assess_enabled():
-                self.track_sources(context, request, environ)
+                self.track_sources(context, request)
 
             with contrast.CS__CONTEXT_TRACKER.lifespan(context):
-                return self.call_with_agent(request, context, environ)
+                return self.call_with_agent(request, context)
 
         return self.call_without_agent(request)
 
@@ -76,8 +58,8 @@ class PyramidMiddleware(BaseMiddleware):
         super(PyramidMiddleware, self).call_without_agent()
         return self.handler(request)
 
-    def call_with_agent(self, request, context, environ):
-        self.log_start_request_analysis(environ.get("PATH_INFO"))
+    def call_with_agent(self, request, context):
+        self.log_start_request_analysis(request.environ.get("PATH_INFO"))
 
         context.timer.set_start("total")
 
@@ -111,8 +93,8 @@ class PyramidMiddleware(BaseMiddleware):
                 contrast.STRING_TRACKER.ageoff()
 
     @fail_safely("Unable to get route coverage", return_value={})
-    def get_route_coverage(self, request):
-        return create_pyramid_routes(request)
+    def get_route_coverage(self):
+        return create_pyramid_routes(self.registry)
 
     @cached_property
     def trigger_node(self):
@@ -129,7 +111,25 @@ class PyramidMiddleware(BaseMiddleware):
 
     @fail_safely("Unable to find new routes")
     def get_view_func(self, request):
-        return get_view_func(request)
+        path = request.environ.get("PATH_INFO", "")
+        if not path:
+            logger.debug("No path info for pyramid request")
+            return None
+
+        mapper = self.registry.queryUtility(IRoutesMapper)
+        routes = mapper.get_routes()
+
+        # Ideally we would like to call get_route but
+        # there is no direct relationship between the wsgi
+        # request path and the name of the route so we must
+        # iterate over all the routes to find it by the path
+        # pyramid_route = mapper.get_route(name)
+
+        matching_routes = [x for x in routes if x.path == path]
+        if not matching_routes:
+            return None
+
+        return get_view_func(self.registry, matching_routes[0])
 
     @fail_safely("Unable to build route", return_value="")
     def build_route(self, view_func, url):
@@ -141,23 +141,23 @@ class PyramidMiddleware(BaseMiddleware):
 
         return HTTPForbidden(explanation=self.OVERRIDE_MESSAGE)
 
-    def track_sources(self, context, request, environ):
+    def track_sources(self, context, request):
         """
-        This method will track necessary information in the environ and all the properties in a Webob request
+        Before we perform environ tracking for pyramid, we ask webob to manipulate the
+        input stream to make it seekable. There is no security risk here, because this
+        simply involves reading raw bytes from wsgi.input into a seekable stream.
 
-        If information is changed or updated by the application after application code executes we do not care
-        because the information is then deemed trusted
+        There is also no risk to correctness despite the fact that `make_body_seekable`
+        resets the stream to position 0. This is because middlewares should not consume
+        this stream without resetting it - so if we receive a partially-consumed stream,
+        an earlier middleware is at fault.
+
+        Only after this occurs do we track environ sources - including the new seekable
+        wsgi.input.
 
         :param context: current request context
         :param request: Pyramid Webob request
-        :param environ: environ dict provided by framework
         :return: None
         """
-        track_environ_sources(WEBOB, context, environ)
-
-        for key, source_type in iteritems(REQUEST_SOURCES):
-            source = getattr(request, key)
-
-            node = build_source_node(WEBOB, key, source_type)
-
-            cs__apply_source(context, node, source, request, source, (), {})
+        request.make_body_seekable()
+        track_environ_sources(WEBOB, context, request.environ)
