@@ -21,13 +21,13 @@ class RoutesMixin(object):
         Method that should run for all middlewares immediately after the application executes.
         """
         if context and request:
-            self.get_routes_on_first_request(request)
+            self.get_routes_on_first_request()
 
             self.check_for_new_routes(context, request)
 
             self.append_route_to_findings(context)
 
-    def get_routes_on_first_request(self, request):
+    def get_routes_on_first_request(self):
         """
         Attempt to do route discovery on the first request
         """
@@ -36,7 +36,7 @@ class RoutesMixin(object):
 
         logger.debug("First request so looking for app routes.")
 
-        routes = self.get_route_coverage(request)
+        routes = self.get_route_coverage()
 
         if not routes or not isinstance(routes, dict):
             logger.debug("Could not find any routes")
