@@ -14,16 +14,17 @@ except ImportError:
 
 from contrast.agent.policy.loader import Policy
 from contrast.agent.protect.policy import apply_protect_patch
-from contrast.agent.assess.policy.utils import (
+from contrast.agent.assess.policy.patches import (
+    assess_method,
+    assess_classmethod,
+    assess_deadzone,
+    assess_property,
     apply_cached_property,
-    _assess_method,
-    classmethod_assess_method,
-    _property_assess_method,
 )
 from contrast.agent.settings_state import SettingsState
 from contrast.agent.assess.policy.source_node import SourceNode
 from contrast.agent.assess.policy.utils import build_method_name
-from contrast.assess_extensions.cs_str import set_attr_on_type
+from contrast.assess_extensions import smart_setattr
 
 from contrast.utils.patch_utils import (
     patch_cls_or_instance,
@@ -58,16 +59,14 @@ def remove_patch_location(owner, name):
         PATCH_LOCATIONS.remove(policy_patch_name)
 
 
-def save_original_method(cls_or_module, cs_method_name, old_method, force=False):
+def save_original_method(cls_or_module, cs_method_name, old_method):
     """
     Attempt to save old_method with the name cs_method_name on the
     class or module
     """
     try:
         # set old function to "cs_assess_{name}"
-        setattr(
-            cls_or_module, cs_method_name, old_method
-        ) if not force else set_attr_on_type(cls_or_module, cs_method_name, old_method)
+        smart_setattr(cls_or_module, cs_method_name, old_method)
     except Exception:
         logger.debug("failed to patch %s.%s", cls_or_module, old_method)
         return False
@@ -134,23 +133,24 @@ def apply_assess_patch(patch_site, patch_policy):
         # get old function/property/method
         old_method = getattr(patch_site, patch_policy.method_name)
 
-    if not save_original_method(
-        patch_site, cs_method_name, old_method, force=patch_policy.is_builtin
-    ):
+    if not save_original_method(patch_site, cs_method_name, old_method):
         return False
 
     if isinstance(old_method, property):
         # newer versions of werkzeug cached_property inherit from property
         # so these are handled here
-        new_method = _property_assess_method
+        new_method = assess_property
     elif cached_property is not None and isinstance(old_method, cached_property):
         # Handle the case in older versions of werkzeug where cached_propery does
         # not inherit from property.
         return apply_cached_property(patch_site, patch_policy, method_name, old_method)
     elif class_method:
-        new_method = classmethod_assess_method
+        new_method = assess_classmethod
     else:
-        new_method = _assess_method
+        # We only support deadzones for methods/functions right now.
+        if patch_policy.is_deadzone and not patch_policy.deadzone_enabled:
+            return False
+        new_method = assess_deadzone if patch_policy.is_deadzone else assess_method
 
     try:
         patch_cls_or_instance(
@@ -161,7 +161,6 @@ def apply_assess_patch(patch_site, patch_policy):
             static_method=static_method,
             class_method=class_method,
             assess_patch=True,
-            force=patch_policy.is_builtin,
         )
         logger.debug("added patch to %s.%s", patch_site, method_name)
     except Exception as e:
@@ -243,7 +242,6 @@ def register_import_hooks(protect_mode=False):
     protect_mode: true.
     If not protect_mode, we will patch all module patches with assess.
     """
-
     policy = Policy()
 
     modules_to_patch = (
@@ -282,6 +280,6 @@ def apply_patch_to_dynamic_property(class_to_patch, property_name, tags):
     policy = Policy()
     patch_policy = policy.add_source_node(dynamic_source_node)
 
-    patch_property(class_to_patch, property_name, _property_assess_method, patch_policy)
+    patch_property(class_to_patch, property_name, assess_property, patch_policy)
 
     return True
