@@ -25,6 +25,7 @@ CONTRAST_KEY = "contrast"
 SOURCES_KEY = "sources"
 PROPAGATION_KEY = "propagators"
 TRIGGERS_KEY = "triggers"
+DEADZONE_KEY = "deadzones"
 
 DB_SOURCE_TYPE = "TAINTED_DATABASE"
 
@@ -149,8 +150,10 @@ JSON_PY2_ONLY = "python2_only"
 JSON_PY3_ONLY = "python3_only"
 JSON_BUILTIN = "builtin"
 JSON_PROTECT_MODE = "protect_mode"
+JSON_CONFIG_OPTION = "config_option"
 
 # End of PolicyNode
 
 TRIGGER_ACTION_DEFAULT = "DEFAULT"
+TRIGGER_ACTION_REDOS = "REDOS"
 TRIGGER_ACTION_SSRF = "SSRF"
