@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 # Copyright © 2020 Contrast Security, Inc.
 # See https://www.contrastsecurity.com/enduser-terms-0317a for more details.
+from contrast.agent.assess.policy.deadzone_node import DeadZoneNode
 from contrast.agent.assess.policy.propagation_node import PropagationNode
 from contrast.agent.assess.policy.source_node import SourceNode
 from contrast.agent.policy.trigger_node import TriggerNode
+from contrast.agent.settings_state import SettingsState
 
 
 class PatchLocationPolicy(object):
@@ -25,6 +27,7 @@ class PatchLocationPolicy(object):
         # must have the same name.
         self.name = node.name
 
+        self.deadzone_nodes = []
         self.source_nodes = []
         self.propagator_nodes = []
         self.trigger_nodes = []
@@ -38,7 +41,9 @@ class PatchLocationPolicy(object):
         # corresponds to a different patch location.
         assert node.name == self.name
 
-        if isinstance(node, PropagationNode):
+        if isinstance(node, DeadZoneNode):
+            self.deadzone_nodes.append(node)
+        elif isinstance(node, PropagationNode):
             self.propagator_nodes.append(node)
         elif isinstance(node, SourceNode):
             self.source_nodes.append(node)
@@ -53,11 +58,34 @@ class PatchLocationPolicy(object):
         return any([node.policy_patch for node in self.all_nodes()])
 
     @property
-    def is_builtin(self):
+    def is_deadzone(self):
         """
-        Indicates whether any nodes at this location should be patched as builtins
+        Indicates if there are any deadzone nodes.
+
+        NOTE: at this time, deadzone nodes and any other nodes are mutually exclusive.
+        That is, all patches will receive the deadzone patch.
         """
-        return any([node.builtin for node in self.all_nodes()])
+        return bool(self.deadzone_nodes)
+
+    @property
+    def deadzone_enabled(self):
+        """
+        This location's deadzone is enabled if at least one deadzone node exists and
+        for ANY existing deadzone node, either:
+        (a) it does not have an associated config option
+        (b) its associated config option indicates that the deadzone should be applied
+        """
+        settings = SettingsState()
+
+        return any(
+            [
+                node.config_option is None
+                # common-config options must default to True. This means options must be
+                # worded in such a way that setting to False will enable the deadzones
+                or settings.config.get(node.config_option) is False
+                for node in self.deadzone_nodes
+            ]
+        )
 
     @property
     def is_protect_mode(self):
@@ -73,7 +101,12 @@ class PatchLocationPolicy(object):
         """
         Returns all nodes in this policy as a list
         """
-        return self.source_nodes + self.propagator_nodes + self.trigger_nodes
+        return (
+            self.source_nodes
+            + self.propagator_nodes
+            + self.trigger_nodes
+            + self.deadzone_nodes
+        )
 
     def __repr__(self):
         return "<{0.__class__.__name__}({0.name})>".format(self)
