@@ -33,9 +33,9 @@ class PathTraversalSinkFeatures(object):
     ]
 
     def check_sink_features(self, attack_vector, attack):
-        new_sample = self.check_custom_code_accessing_system_files(
+        new_sample = self._check_custom_code_accessing_system_files(
             attack_vector
-        ) or self.check_file_security_bypass(attack_vector)
+        ) or self._check_file_security_bypass(attack_vector)
 
         if new_sample:
             if attack is None:
@@ -47,63 +47,67 @@ class PathTraversalSinkFeatures(object):
 
         return attack
 
-    def check_custom_code_accessing_system_files(self, attack_vector):
+    def _check_custom_code_accessing_system_files(self, attack_vector):
         if (
-            self.is_custom_code_access_sysfile_enabled
-            and self.is_custom_code_accessing_file_system(attack_vector)
+            self._is_custom_code_access_sysfile_enabled
+            and PathTraversalSinkFeatures._is_custom_code_accessing_file_system(
+                attack_vector
+            )
         ):
             logger.debug(
                 "Found custom code trying to access system file: %s", attack_vector
             )
-            return self.create_path_traversal_sample(
+            return self._create_path_traversal_sample(
                 attack_vector,
                 PathTraversalSemanticAnalysisDetails.CUSTOM_CODE_ACCESSING_SYSTEM_FILES,
             )
 
         return None
 
-    def check_file_security_bypass(self, attack_vector):
+    def _check_file_security_bypass(self, attack_vector):
         if (
-            self.is_common_file_exploits_enabled
-            and self.contains_known_attack_signatures(attack_vector)
+            self._is_common_file_exploits_enabled
+            and PathTraversalSinkFeatures._contains_known_attack_signatures(
+                attack_vector
+            )
         ):
             logger.debug(
                 "Found attempt to bypass file security checks: %s", attack_vector
             )
-            return self.create_path_traversal_sample(
+            return self._create_path_traversal_sample(
                 attack_vector,
                 PathTraversalSemanticAnalysisDetails.COMMON_FILE_EXPLOITS,
             )
 
         return None
 
-    def create_path_traversal_sample(self, attack_vector, rep_code):
+    def _create_path_traversal_sample(self, attack_vector, rep_code):
         sample = self.build_sample(None, attack_vector)
         sample.path_traversal_semantic.path = attack_vector
         sample.path_traversal_semantic.findings.append(rep_code)
         return sample
 
     @cached_property
-    def is_custom_code_access_sysfile_enabled(self):
+    def _is_custom_code_access_sysfile_enabled(self):
         return self.settings.is_rep_feature_enabled_for_rule(
             self.name, self.CUSTOM_CODE_CONFIG_KEY
         )
 
     @cached_property
-    def is_common_file_exploits_enabled(self):
+    def _is_common_file_exploits_enabled(self):
         return self.settings.is_rep_feature_enabled_for_rule(
             self.name, self.COMMON_FILE_EXPLOITS_KEY
         )
 
     @staticmethod
-    def is_custom_code_accessing_file_system(path):
+    def _is_custom_code_accessing_file_system(path):
         return (
-            PathTraversalSinkFeatures.is_system_file(path)
+            PathTraversalSinkFeatures._is_system_file(path)
             and StackTraceUtils.in_custom_code()
         )
 
     @staticmethod
-    def contains_known_attack_signatures(path):
+    def _contains_known_attack_signatures(path):
         unquoted = unquote(path)
         unescaped = unquoted.encode("utf-8").decode("unicode-escape")
 
@@ -128,7 +132,7 @@ class PathTraversalSinkFeatures(object):
         )
 
     @staticmethod
-    def is_system_file(path):
+    def _is_system_file(path):
         if not path:
             return False
         unquoted = unquote(path)
