@@ -187,11 +187,10 @@ class CmdInjection(BaseRule, CommandInjectionREPMixin):
             normalized_command = self._normalize_str(command)
 
             parameters = request.params.dict_of_lists()
+
             for parameter_key, parameter_values in iteritems(parameters):
-                if parameter_values:
-                    param = self._get_param_in_command(
-                        parameter_values, normalized_command
-                    )
+                param = self._get_param_in_command(parameter_values, normalized_command)
+                if param:
                     return parameter_key, param
 
         return None
