@@ -12,7 +12,7 @@ from contrast.utils.exceptions.security_exception import SecurityException
 from contrast.utils.string_utils import ends_with_any
 from contrast.utils.stack_trace_utils import StackTraceUtils
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
