@@ -4,7 +4,7 @@
 from contrast.agent.disable_reaction import DisableReaction
 from contrast.api.settings_pb2 import Reaction
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
