@@ -9,7 +9,7 @@ from contrast.agent.settings_state import SettingsState
 from contrast.api.dtm_pb2 import Activity, ServerActivity, ObservedRoute
 from contrast.utils.timer import Timer
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
