@@ -5,7 +5,7 @@ from contrast.extern.six import string_types, binary_type
 
 from contrast.agent import scope
 from contrast.agent.policy.loader import Policy
-from contrast.agent.assess.policy.trigger_policy import TriggerPolicy
+from contrast.agent.assess.policy import trigger_policy
 from contrast.utils.decorators import fail_safely
 
 
@@ -23,4 +23,4 @@ def apply_rule(module_name, method_name, result, args, kwargs):
     trigger_nodes = trigger_rule.find_trigger_nodes(module_name, method_name)
 
     with scope.trigger_scope():
-        TriggerPolicy.apply(trigger_rule, trigger_nodes, result, args, kwargs)
+        trigger_policy.apply(trigger_rule, trigger_nodes, result, args, kwargs)
