@@ -8,14 +8,15 @@ import contrast
 from contrast.agent import scope
 from contrast.agent.protect.rule.sqli_rule import SqlInjection
 from contrast.agent.policy.loader import Policy
-from contrast.agent.assess.policy.utils import skip_analysis
-from contrast.agent.assess.policy.trigger_policy import TriggerPolicy
+from contrast.agent.assess.policy.analysis import skip_analysis
+from contrast.agent.assess.policy import trigger_policy
 from contrast.agent.settings_state import SettingsState
 from contrast.applies import (
     DATABASE_SQLITE,
     DATABASE_CASSANDRA,
     DATABASE_PG,
     DATABASE_MYSQL,
+    DATABASE_SQL_ALCHEMY,
 )
 from contrast.utils.decorators import fail_safely
 
@@ -29,6 +30,7 @@ ADAPTER_TO_DATABASE = {
     "pycassa": DATABASE_CASSANDRA,
     "psycopg2": DATABASE_PG,
     "pymysql": DATABASE_MYSQL,
+    "sqlalchemy": DATABASE_SQL_ALCHEMY,
 }
 
 
@@ -47,9 +49,6 @@ def assess_rule(context, adapter, method, result, args, kwargs):
     if scope.in_trigger_scope():
         return
 
-    # TODO: PYT-388 this logic is actually present in the protect rule as well. Once
-    # all db patches have migrated to this new API, we should move this to the
-    # common rule applicator so that it is not duplicated.
     context.activity.query_count += 1
 
     policy = Policy()
@@ -58,7 +57,7 @@ def assess_rule(context, adapter, method, result, args, kwargs):
     trigger_nodes = rule.find_trigger_nodes("{}.Cursor".format(adapter), method)
 
     with scope.trigger_scope():
-        TriggerPolicy.apply(rule, trigger_nodes, result, args, kwargs)
+        trigger_policy.apply(rule, trigger_nodes, result, args, kwargs)
 
 
 def apply_rule(adapter, method, orig_func, args, kwargs):
@@ -88,21 +87,8 @@ def apply_rule(adapter, method, orig_func, args, kwargs):
     """
     context = contrast.CS__CONTEXT_TRACKER.current()
 
-    if context is not None and SettingsState().is_protect_enabled() and len(args) > 1:
-        # args[0] is self, args[1] should be the query
-        sql = args[1]
-
-        database = ADAPTER_TO_DATABASE.get(adapter, adapter)
-
-        # TODO: PYT-986: remove creating fake policy node and patch loc policy
-        from contrast.agent.policy.patch_location_policy import PatchLocationPolicy
-        from contrast.agent.policy.trigger_node import TriggerNode
-
-        trigger_node = TriggerNode(database, "unused", True, method, "ARG_0")
-        patch_policy = PatchLocationPolicy(trigger_node)
-
-        rule = SettingsState().defend_rules.get(SqlInjection.NAME)
-        rule.protect(patch_policy, sql, args, kwargs)
+    if context is not None:
+        _protect_rule(context, adapter, method, args, kwargs)
 
     try:
         result = orig_func(*args, **kwargs)
@@ -114,3 +100,27 @@ def apply_rule(adapter, method, orig_func, args, kwargs):
             assess_rule(context, adapter, method, result, args, kwargs)
 
     return result
+
+
+@fail_safely("Error running SQLi protect rule")
+def _protect_rule(context, adapter, method, args, kwargs):
+    """
+    Run protect SQLi analysis if it's enabled.
+    """
+    if not SettingsState().is_protect_enabled() or len(args) <= 1:
+        return
+
+    # args[0] is self, args[1] is the query
+    sql = args[1]
+
+    database = ADAPTER_TO_DATABASE.get(adapter, adapter)
+
+    # TODO: PYT-986: remove creating fake policy node and patch loc policy
+    from contrast.agent.policy.patch_location_policy import PatchLocationPolicy
+    from contrast.agent.policy.trigger_node import TriggerNode
+
+    trigger_node = TriggerNode(database, "unused", True, method, "ARG_0")
+    patch_policy = PatchLocationPolicy(trigger_node)
+
+    rule = SettingsState().defend_rules.get(SqlInjection.NAME)
+    rule.protect(patch_policy, sql, args, kwargs)
