@@ -15,9 +15,15 @@ typedef struct thread_scope {
     int contrast_scope;
     int propagation_scope;
     int trigger_scope;
+    int eval_scope;
 } thread_scope_t;
 
 
+#define DECREMENT_SCOPE(SCOPE, NAME) do {   \
+    if ((SCOPE)->NAME > 0) (SCOPE)->NAME--;     \
+} while (0)
+
+
 static pthread_key_t thread_key;
 static pthread_once_t once_key = PTHREAD_ONCE_INIT;
 /* Forward declaration */
@@ -77,9 +83,19 @@ inline int should_propagate(void) {
     return !(scope->contrast_scope || scope->propagation_scope || scope->trigger_scope);
 }
 
+inline int in_eval_scope(void) {
+    thread_scope_t *scope = get_scope();
+
+    if (scope == NULL) {
+        return 0;
+    }
+
+    return scope->eval_scope;
+}
+
 
 PyObject *enter_scope(PyObject *self, PyObject *args) {
-    int scope_id;
+    ScopeLevel_t scope_id;
     thread_scope_t *scope;
 
     if ((scope = get_scope()) == NULL) {
@@ -90,19 +106,27 @@ PyObject *enter_scope(PyObject *self, PyObject *args) {
     if (!PyArg_ParseTuple(args, "i", &scope_id))
         return NULL;
 
-    if (scope_id == CONTRAST_SCOPE)
+    switch (scope_id) {
+    case CONTRAST_SCOPE:
         scope->contrast_scope++;
-    else if (scope_id == PROPAGATION_SCOPE)
+        break;
+    case PROPAGATION_SCOPE:
         scope->propagation_scope++;
-    else if (scope_id == TRIGGER_SCOPE)
+        break;
+    case TRIGGER_SCOPE:
         scope->trigger_scope++;
+        break;
+    case EVAL_SCOPE:
+        scope->eval_scope++;
+        break;
+    }
 
     Py_RETURN_NONE;
 }
 
 
 PyObject *exit_scope(PyObject *self, PyObject *args) {
-    int scope_id;
+    ScopeLevel_t scope_id;
     thread_scope_t *scope;
 
     if ((scope = get_scope()) == NULL) {
@@ -113,19 +137,27 @@ PyObject *exit_scope(PyObject *self, PyObject *args) {
     if (!PyArg_ParseTuple(args, "i", &scope_id))
         return NULL;
 
-    if (scope_id == CONTRAST_SCOPE && scope->contrast_scope > 0)
-        scope->contrast_scope--;
-    else if (scope_id == PROPAGATION_SCOPE && scope->propagation_scope > 0)
-        scope->propagation_scope--;
-    else if (scope_id == TRIGGER_SCOPE && scope->trigger_scope > 0)
-        scope->trigger_scope--;
+    switch (scope_id) {
+    case CONTRAST_SCOPE:
+        DECREMENT_SCOPE(scope, contrast_scope);
+        break;
+    case PROPAGATION_SCOPE:
+        DECREMENT_SCOPE(scope, propagation_scope);
+        break;
+    case TRIGGER_SCOPE:
+        DECREMENT_SCOPE(scope, trigger_scope);
+        break;
+    case EVAL_SCOPE:
+        DECREMENT_SCOPE(scope, eval_scope);
+        break;
+    }
 
     Py_RETURN_NONE;
 }
 
 
 PyObject *in_scope(PyObject *self, PyObject *args) {
-    int scope_id;
+    ScopeLevel_t scope_id;
     thread_scope_t *scope;
 
     if ((scope = get_scope()) == NULL) {
@@ -136,12 +168,16 @@ PyObject *in_scope(PyObject *self, PyObject *args) {
     if (!PyArg_ParseTuple(args, "i", &scope_id))
         return NULL;
 
-    if (scope_id == CONTRAST_SCOPE)
+    switch (scope_id) {
+    case CONTRAST_SCOPE:
         return PyBool_FromLong(scope->contrast_scope);
-    else if (scope_id == PROPAGATION_SCOPE)
+    case PROPAGATION_SCOPE:
         return PyBool_FromLong(scope->propagation_scope);
-    else if (scope_id == TRIGGER_SCOPE)
+    case TRIGGER_SCOPE:
         return PyBool_FromLong(scope->trigger_scope);
+    case EVAL_SCOPE:
+        return PyBool_FromLong(scope->eval_scope);
+    }
 
     Py_RETURN_FALSE;
 }
@@ -183,10 +219,11 @@ PyObject *set_thread_scope(PyObject *self, PyObject *py_scope) {
 
     if (!PyArg_ParseTuple(
             py_scope,
-            "iii",
+            "iiii",
             &scope.contrast_scope,
             &scope.propagation_scope,
-            &scope.trigger_scope)) {
+            &scope.trigger_scope,
+            &scope.eval_scope)) {
         PyErr_Format(PyExc_RuntimeError, "Failed to parse scope from tuple");
         return NULL;
     }
@@ -232,10 +269,11 @@ PyObject *get_thread_scope(PyObject *self, PyObject *args) {
     }
 
     return Py_BuildValue(
-        "(iii)",
+        "(iiii)",
         scope->contrast_scope,
         scope->propagation_scope,
-        scope->trigger_scope
+        scope->trigger_scope,
+        scope->eval_scope
     );
 }
 
