@@ -7,9 +7,12 @@
 #include <Python.h>
 
 
-#define CONTRAST_SCOPE      0
-#define PROPAGATION_SCOPE   1
-#define TRIGGER_SCOPE       2
+typedef enum {
+    CONTRAST_SCOPE = 0,
+    PROPAGATION_SCOPE,
+    TRIGGER_SCOPE,
+    EVAL_SCOPE,
+} ScopeLevel_t;
 
 
 PyObject *enter_scope(PyObject *self, PyObject *args);
@@ -24,3 +27,4 @@ void exit_contrast_scope(void);
 void enter_propagation_scope(void);
 void exit_propagation_scope(void);
 int should_propagate(void);
+int in_eval_scope(void);
