@@ -267,6 +267,11 @@ class Assess(ConfigBuilder):
                 default_value=[],
                 type_cast=utils.parse_disabled_rules,
             ),
+            ConfigOption(
+                name="stacktraces",
+                default_value="ALL",
+                type_cast=utils.parse_stacktraces_options,
+            ),
         ]
 
 
