@@ -6,31 +6,21 @@ import sys
 from contrast.extern.wrapt import register_post_import_hook
 
 from contrast.agent.policy import patch_manager
+from contrast.utils.patch_utils import patch_cls_or_instance
 from contrast.utils.assess.stream_utils import stream_patch_body
-from contrast.assess_extensions import cs_str
 
 from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
 
-def build_patch(orig_func, method_name):
-    def patched_func(self, *args, **kwargs):
-        bound_method = functools.partial(orig_func, self)
-        return stream_patch_body(method_name, bound_method, self, *args, **kwargs)
-
-    patched_func.__name__ = method_name
-    return patched_func
+def patched_func(orig_func, patch_policy, self, *args, **kwargs):
+    bound_method = functools.partial(orig_func, self)
+    return stream_patch_body(orig_func.__name__, bound_method, self, *args, **kwargs)
 
 
 def patch_method(io_type, method_name):
-    orig_func = getattr(io_type, method_name)
-    if patch_manager.is_patched(orig_func):
-        return
-
-    new_func = build_patch(orig_func, method_name)
-    cs_str.set_attr_on_type(io_type, method_name, new_func)
-    patch_manager.register_patch(io_type, method_name, orig_func)
+    patch_cls_or_instance(io_type, method_name, patched_func)
 
 
 def patch_getvalue(io_module):
@@ -65,5 +55,5 @@ def reverse_patches():
         return
 
     patch_manager.reverse_patches_by_owner(io_module)
-    patch_manager.reverse_patches_by_owner(io_module.BytesIO, force=True)
-    patch_manager.reverse_patches_by_owner(io_module.StringIO, force=True)
+    patch_manager.reverse_patches_by_owner(io_module.BytesIO)
+    patch_manager.reverse_patches_by_owner(io_module.StringIO)
