@@ -15,7 +15,7 @@ from contrast.agent.policy.loader import Policy
 from contrast.utils.decorators import fail_safely
 from contrast.utils.patch_utils import patch_cls_or_instance
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
