@@ -8,7 +8,7 @@ from contrast.agent.policy import patch_manager
 from contrast.assess_extensions import cs_str
 from contrast.utils.patch_utils import patch_cls_or_instance
 
-import logging
+from contrast.extern import structlog as logging
 
 logger = logging.getLogger("contrast")
 
