@@ -5,13 +5,13 @@
 import mock
 
 from contrast.agent.assess.apply_trigger import build_finding
-from contrast.agent.assess.policy.trigger_policy import TriggerPolicy
+from contrast.agent.assess.policy import trigger_policy
 from contrast.api.dtm_pb2 import UserInput
 from contrast.api.settings_pb2 import InputAnalysis, InputAnalysisResult
 
 apply_trigger = mock.patch(
-    "contrast.agent.assess.policy.trigger_policy.TriggerPolicy.apply",
-    side_effect=TriggerPolicy.apply,
+    "contrast.agent.assess.policy.trigger_policy.apply",
+    side_effect=trigger_policy.apply,
 )
 build_finding = mock.patch(
     "contrast.agent.assess.apply_trigger.build_finding", side_effect=build_finding
