@@ -11,6 +11,9 @@ logger = logging.getLogger("contrast")
 
 string_types = (six.string_types) + (six.binary_type, bytearray)
 
+list_iterator = type(iter(list()))
+dict_iterator = type(iter(dict()))
+
 
 def is_iterable(value):
     """
@@ -45,18 +48,40 @@ def len_or_zero(value):
 
 
 def safe_iterator(it):
-    try:
-        orig_pos = 0
-        can_seek = False
+    if isinstance(it, (list_iterator, dict_iterator)):
+        logger.debug("WARNING: skipping iteration of non-seekable iterator: %s", it)
+        return
 
-        if hasattr(it, "tell") and hasattr(it, "seek"):
-            orig_pos = it.tell()
-            can_seek = True
+    if isinstance(it, (str, list, dict)):
+        for x in it:
+            yield x
+        return
+
+    if not (hasattr(it, "tell") and hasattr(it, "seek")):
+        logger.debug("WARNING: skipping iteration of non-seekable object: %s", it)
+        return
+
+    try:
+        orig_pos = it.tell()
 
         for x in it:
             yield x
     except Exception:
         logger.debug("safe_iterator failed to iterate over %s", it)
     finally:
-        if can_seek:
-            it.seek(orig_pos)
+        it.seek(orig_pos)
+
+
+def safe_getattr(obj, attr, default=None):
+    """
+    A getattr implementation that returns a default even if an exception is raised
+
+    Some classes may override __getattribute__ to raise exceptions when certain
+    attributes are accessed. When we are dealing with objects from the outside world,
+    we want to be careful in our attribute access to avoid such exceptions and provide
+    a safe default.
+    """
+    try:
+        return getattr(obj, attr, default)
+    except Exception:
+        return default
