@@ -37,13 +37,13 @@ class BaseStreamProxy(ObjectProxy):
     See https://wrapt.readthedocs.io/en/latest/wrappers.html#proxy-object-attributes
     for details about object property attributes.
 
-    TODO: PYT-917 In the future we may want to instrument write and writelines. This would
-        require us to treat the stream more like a propagator than a source because
-        trusted data could be written to it.
+    TODO: PYT-917 In the future we may want to instrument write and writelines. This
+        would require us to treat the stream more like a propagator than a source
+        because trusted data could be written to it.
 
-    TODO: PYT-917 We may eventually need to consider the less common __iter__ method, which
-        is currently not instrumented. Werkzeug (at least) does not use __iter__ when
-        parsing wsgi.input; we may have to investigate WebOb's parser as well. It's
+    TODO: PYT-917 We may eventually need to consider the less common __iter__ method,
+        which is currently not instrumented. Werkzeug (at least) does not use __iter__
+        when parsing wsgi.input; we may have to investigate WebOb's parser as well. It's
         also possible that the underlying implementation of __iter__ calls an already
         instrumented method for BytesIO, StringIO, etc.
 
@@ -159,10 +159,12 @@ def stream_patch_body(method_name, orig_func, self, *args, **kwargs):
 @fail_safely("Error instrumenting source stream")
 def instrument_source_stream(stream):
     """
-    Mark the provided stream as a source, and instrument methods that produce tracked content.
-    This must be a stream that we have proxied. i.e., it has the `CS__METHOD_NAMES` attribute.
+    Mark the provided stream as a source, and instrument methods that produce tracked
+    content. This must be a stream that we have proxied. i.e., it has the
+    `CS__METHOD_NAMES` attribute.
 
-    @param stream: stream object proxied by BaseStreamProxy (must have the CS__METHOD_NAMES attribute)
+    @param stream: stream object proxied by BaseStreamProxy (must have the
+        CS__METHOD_NAMES attribute)
     """
     stream.cs__source = True
     for method_name in stream.CS__METHOD_NAMES:
@@ -173,8 +175,8 @@ def _instrument_source_stream_method(stream, method_name):
     """
     Instrument a method on a stream object.
 
-    Only this particular stream instance is instrumented, because the patch is not applied
-    at the class level.
+    Only this particular stream instance is instrumented, because the patch is not
+    applied at the class level.
 
     @param stream: file-like object conforming to to PEP 333's wsgi.input specification
     @param method_name: string, the name of the method to instrument
@@ -185,18 +187,19 @@ def _instrument_source_stream_method(stream, method_name):
             "WARNING: source stream missing expected attribute: %s", method_name
         )
         return
-    new_method = _build_patch(orig_method)
+    new_method = _build_patch(stream, orig_method)
     setattr(stream, method_name, new_method)
 
 
-def _build_patch(orig_method):
+def _build_patch(stream, orig_method):
     """
     Create a patch for the provided stream method. This is an instance method, so it is
-    bound to a specific stream instance. This means that the `self` parameter needs not
-    be passed to the original method.
+    bound to a specific stream instance.
 
-    We access the underlying `self` of the bound instance method using the __self__
-    back-reference.
+    Note that we cannot pass orig_method.__self__ to apply_stream_source. This is
+    because if we're instrumenting a proxied stream, orig_method.__self__ points to the
+    wrapped instance, not the wrapper. Only the wrapper has the cs__* attributes that we
+    need for source application.
 
     @param orig_method: original instance method object
     @return method object that is an instrumented version of the original
@@ -204,9 +207,7 @@ def _build_patch(orig_method):
 
     def patched_method(*args, **kwargs):
         result = orig_method(*args, **kwargs)
-        apply_stream_source(
-            orig_method.__name__, result, orig_method.__self__, result, args, kwargs
-        )
+        apply_stream_source(orig_method.__name__, result, stream, result, args, kwargs)
         return result
 
     patched_method.__name__ = orig_method.__name__
