@@ -25,6 +25,10 @@ CONFIG_LOCATIONS = [
 
 CONFIG_FILE_NAMES = ["contrast_security.yaml", "contrast_security.yml"]
 
+# Valid options are defined in the spec:
+# https://bitbucket.org/contrastsecurity/assess-specifications/src/master/vulnerability/capture-stacktrace.md
+STACKTRACE_OPTIONS = ["ALL", "SOME", "NONE"]
+
 
 def get_hostname():
     """
@@ -158,6 +162,14 @@ def parse_disabled_rules(disabled_rules):
     return [rule.lower() for rule in disabled_rules.split(",")]
 
 
+def parse_stacktraces_options(option):
+    option = option.upper()
+    if option in STACKTRACE_OPTIONS:
+        return option
+
+    return "ALL"
+
+
 PROTOBUF_MODES = {
     "monitor": ProtectionRule.MONITOR,
     "block": ProtectionRule.BLOCK,
