@@ -148,7 +148,7 @@ class DistributionContext(Singleton):
         data structure to maintain the list of top level directories or file names belonging to that namespace.
 
         @param dist: Distribution object used to determine how many top level importable packages/modules exist in it
-        @type dist: pip._vendor.pkg_resources.DistInfoDistribution
+        @type dist: pkg_resources.DistInfoDistribution
         """
         for tld in get_top_level_directories(dist):
             # The namespace dist we support is building a namespace package
