@@ -55,7 +55,6 @@ def patch_cls_or_instance(
     static_method=False,
     class_method=False,
     assess_patch=False,
-    force=False,
 ):
     """
     Apply a patch to given module, class, or object instance
@@ -104,7 +103,7 @@ def patch_cls_or_instance(
         )
         return
 
-    patch_manager.patch(patch_target, method_name, curried_function, force=force)
+    patch_manager.patch(patch_target, method_name, curried_function)
 
 
 def patch_property(
@@ -147,6 +146,12 @@ def get_loaded_modules(use_for_patching=False):
     called to enable patching. In this case the modules are sorted (to
     provide deterministic behavior) and also the modules_to_ignore list is used.
 
+    NOTE: This method gets called multiple times during the course of agent
+    initialization. Ideally it would be called only once for PERF optimization,
+    but because sys.modules is global to all threads, we can't guarantee its contents
+    will be the same and that a race condition won't happen which would add modules
+    across different threads.
+
     :return: dict of name and module as value
     """
     if not use_for_patching:
@@ -158,15 +163,29 @@ def get_loaded_modules(use_for_patching=False):
         dict(
             (name, module)
             for name, module in sorted(iteritems(sys.modules))
-            if inspect.ismodule(module) and not module_is_ignored(name)
+            if inspect.ismodule(module)
+            and not module_is_ignored(name)
+            and not is_so_module(module)
         )
     )
 
-    # TODO: PYT-683 filter out .so modules
-
     return filtered
 
 
+def is_so_module(module):
+    """
+    Return True if module is an .so file, such as
+    ".../readline.cpython-38-darwin.so"
+
+    :param module: python module object
+    :return: bool
+    """
+    if not hasattr(module, "__file__") or module.__file__ is None:
+        return False
+
+    return module.__file__.endswith(".so")
+
+
 def is_patchable(obj):
     if inspect.ismodule(obj):
         return False
