@@ -24,21 +24,17 @@ def make_sure_path_exists(log_path):
 
 class ServiceUtil(object):
     SERVICE_EXE_NAME = "contrast-service"
-    WINDOWS_SERVICE_EXTENSION = ".exe"
     BASE_SERVICE_DIRECTORY = "service_executables"
 
     LINUX_PLATFORM = "linux"
     MAC_PLATFORM = "darwin"
-    WINDOWS_PLATFORM = "windows"
 
     LINUX_SERVICE_DIRECTORY = LINUX_PLATFORM
     MAC_SERVICE_DIRECTORY = "mac"
-    WINDOWS_SERVICE_DIRECTORY = WINDOWS_PLATFORM
 
     SUPPORTED_PLATFORM_DIRECTORIES = {
         LINUX_PLATFORM: LINUX_SERVICE_DIRECTORY,
         MAC_PLATFORM: MAC_SERVICE_DIRECTORY,
-        WINDOWS_PLATFORM: WINDOWS_SERVICE_DIRECTORY,
     }
 
     def __init__(self, service_log_path):
@@ -89,8 +85,6 @@ class ServiceUtil(object):
         )
         platform_directory = ServiceUtil.get_platform_directory()
         exe_name = ServiceUtil.SERVICE_EXE_NAME
-        if platform_directory == ServiceUtil.WINDOWS_SERVICE_DIRECTORY:
-            exe_name += ServiceUtil.WINDOWS_SERVICE_EXTENSION
         return path.join(base_service_directory, platform_directory, exe_name)
 
     @staticmethod
