@@ -212,10 +212,10 @@ class StackTraceUtils(object):
             )
             formatted = file_name.replace(virtual_site, "")
 
-        if file_name.startswith(os.getcwd()):
+        elif file_name.startswith(os.getcwd()):
             formatted = file_name.replace(os.getcwd(), "")
 
-        if not formatted:
+        else:
             for sys_path in StackTraceUtils.SORTED_SYS_PATH:
                 if file_name.startswith(sys_path):
                     formatted = file_name.replace(sys_path, "")
@@ -259,7 +259,12 @@ class StackTraceUtils(object):
         :param file_name: string of file_name without file type (contrast.utils.stack_trace_utils)
         :return: True if no active libraries are in the file_name else False
         """
-        active_libraries_names = get_active_library_names_from_pkg()
+        active_libraries_names = [
+            # exclude vulnpy - a purposely-vulnerable library
+            lib
+            for lib in get_active_library_names_from_pkg()
+            if lib != "vulnpy"
+        ]
         for library_name in active_libraries_names:
             if file_name.startswith(library_name):
                 return False
